@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0505';
 
 use Carp;
 use List::Util qw( first );
@@ -128,7 +128,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0504
+version 0.0505
 
 =head1 SYNOPSIS
 
@@ -148,24 +148,27 @@ version 0.0504
   $msn = Music::ScaleNote->new(
     scale_note  => 'C',
     scale_name  => 'major',
+  );
+
+  $note = $msn->get_offset(
+    note_name   => 60,
     note_format => 'midinum',
     offset      => -1,
-    verbose     => 1,
   );
-  $note = $msn->get_offset( note_name => 60 );
   print $note->format('midinum'), "\n"; # 59
 
 =head1 DESCRIPTION
 
-A C<Music::ScaleNote> object manipulates the position of a note in a scale.
+A C<Music::ScaleNote> object manipulates the position of a note in a
+scale.
 
 Given a B<scale_name>, a B<scale_note>, a starting B<note_name>, the
-B<note_format>, and a scale position B<offset>, this module computes the new
-note.
+B<note_format>, and a scale position B<offset>, the new note is
+computed.
 
-So for scale C<C D# F G A#> (C pentatonic minor), note name C<C4> (given the
-ISO format), and offset C<1> (move one scale step to the right), this module
-will return C<D#4>.
+So for scale C<C D# F G A#> (C pentatonic minor), note name C<C4>
+(given the ISO format), and offset C<1> (move one scale step to the
+right), the note C<D#4> is returned.
 
 For offset of C<-1>, the note C<A#3> is returned.
 
